@@ -186,7 +186,7 @@ gdm_daemonify (void)
 
     pid = fork ();
     if (pid > 0) {
-        gchar *pidfile = GDM_PID_FILE;
+        gchar *pidfile = gdm_get_value_string (GDM_KEY_PID_FILE);
 
         errno = 0;
 	if ((pf = gdm_safe_fopen_w (pidfile)) != NULL) {
@@ -386,7 +386,7 @@ gdm_final_cleanup (void)
 
 	closelog ();
 
-	pidfile = GDM_PID_FILE;
+	pidfile = gdm_get_value_string (GDM_KEY_PID_FILE);
 	if (pidfile != NULL) {
 		VE_IGNORE_EINTR (g_unlink (pidfile));
 	}
@@ -679,7 +679,6 @@ gdm_cleanup_children (void)
     gint exitstatus = 0, status;
     GdmDisplay *d = NULL;
     gboolean crashed;
-    gboolean sysmenu;
 
     /* Pid and exit status of slave that died */
     pid = waitpid (-1, &exitstatus, WNOHANG);
@@ -767,9 +766,7 @@ gdm_cleanup_children (void)
     d->slavepid = 0;
     d->dispstat = DISPLAY_DEAD;
 
-    sysmenu = gdm_get_value_bool_per_display (d->name, GDM_KEY_SYSTEM_MENU);
-
-    if ( ! sysmenu &&
+    if ( ! gdm_get_value_bool (GDM_KEY_SYSTEM_MENU) &&
 	(status == DISPLAY_RESTARTGDM ||
 	 status == DISPLAY_REBOOT ||
 	 status == DISPLAY_SUSPEND ||
@@ -789,8 +786,8 @@ gdm_cleanup_children (void)
 
     if (status == DISPLAY_RUN_CHOOSER) {
 	    /* use the chooser on the next run (but only if allowed) */
-	    if (sysmenu && 
-		gdm_get_value_bool_per_display (d->name, GDM_KEY_CHOOSER_BUTTON))
+	    if (gdm_get_value_bool (GDM_KEY_SYSTEM_MENU) &&
+		gdm_get_value_bool (GDM_KEY_CHOOSER_BUTTON))
 		    d->use_chooser = TRUE;
 	    status = DISPLAY_REMANAGE;
 	    /* go around the display loop detection, these are short
@@ -1433,8 +1430,7 @@ main (int argc, char *argv[])
     /* XDM compliant error message */
     if G_UNLIKELY (getuid () != 0) {
 	    /* make sure the pid file doesn't get wiped */
-	    gdm_error (_("Only root wants to run GDM\n"));
-	    exit (-1);
+	    gdm_fail (_("Only root wants to run GDM\n"));
     }
 
     main_loop = g_main_loop_new (NULL, FALSE);
@@ -1449,13 +1445,6 @@ main (int argc, char *argv[])
     sig.sa_flags = SA_RESTART;
     sigemptyset (&sig.sa_mask);
 
-    /* Parse configuration file */
-    gdm_config_parse ();
-
-    /*
-     * Do not call gdm_fail before calling gdm_config_parse ()
-     * since the gdm_fail function uses config data
-     */
     if G_UNLIKELY (sigaction (SIGTERM, &sig, NULL) < 0) 
 	gdm_fail (_("%s: Error setting up %s signal handler: %s"),
 		  "main", "TERM", strerror (errno));
@@ -1467,7 +1456,10 @@ main (int argc, char *argv[])
     /* get the name of the root user */
     gdm_root_user ();
 
-    pidfile = GDM_PID_FILE;
+    /* Parse configuration file */
+    gdm_config_parse ();
+
+    pidfile = gdm_get_value_string (GDM_KEY_PID_FILE);
 
     /* Check if another gdm process is already running */
     if (g_access (pidfile, R_OK) == 0) {
@@ -1482,6 +1474,8 @@ main (int argc, char *argv[])
 	    kill (pidv, 0) == 0 &&
 	    linux_only_is_running (pidv)) {
 		/* make sure the pid file doesn't get wiped */
+		gdm_set_value_string (GDM_KEY_PID_FILE, NULL);
+		pidfile = NULL;
 		VE_IGNORE_EINTR (fclose (pf));
 		gdm_fail (_("GDM already running. Aborting!"));
 	}
@@ -2300,20 +2294,10 @@ gdm_handle_message (GdmConnection *conn, const char *msg, gpointer data)
 			/* send ack */
 			send_slave_ack (d, NULL);
 		}
-	} else if (strncmp (msg, GDM_SOP_SUSPEND_MACHINE " ",
-			    strlen (GDM_SOP_SUSPEND_MACHINE " ")) == 0) {
-		GdmDisplay *d;
-		long slave_pid;
-		gboolean sysmenu;
-
-		if (sscanf (msg, GDM_SOP_SUSPEND_MACHINE " %ld", &slave_pid) != 1)
-			return;
-		d = gdm_display_lookup (slave_pid);
-
+	} else if (strcmp (msg, GDM_SOP_SUSPEND_MACHINE) == 0) {
 		gdm_info (_("Master suspending..."));
-
-		sysmenu = gdm_get_value_bool_per_display (d->name, GDM_KEY_SYSTEM_MENU);
-		if (sysmenu && gdm_get_value_string (GDM_KEY_SUSPEND) != NULL) {
+		if (gdm_get_value_string (GDM_KEY_SUSPEND) != NULL &&
+		    gdm_get_value_string (GDM_KEY_SYSTEM_MENU)) {
 			suspend_machine ();
 		}
 	} else if (strncmp (msg, GDM_SOP_CHOSEN_THEME " ",
@@ -3052,13 +3036,9 @@ gdm_handle_user_message (GdmConnection *conn, const gchar *msg, gpointer data)
  
 	} else if (strncmp (msg, GDM_SUP_GET_SERVER_DETAILS " ",
 		     strlen (GDM_SUP_GET_SERVER_DETAILS " ")) == 0) {
-		const gchar  *server   = &msg[strlen (GDM_SUP_GET_SERVER_DETAILS " ")];
-		gchar       **splitstr = g_strsplit (server, " ", 2);
-		GdmXserver   *svr      = NULL;
-
-		if (splitstr != NULL && splitstr[0] != NULL) {
-			svr = gdm_find_xserver ((gchar *)splitstr[0]);
-		}
+		const gchar *server = &msg[strlen (GDM_SUP_GET_SERVER_DETAILS " ")];
+		gchar   **splitstr = g_strsplit (server, " ", 2);
+		GdmXserver  *svr   = gdm_find_xserver ((gchar *)splitstr[0]);
 
 		if (svr != NULL) {
 			if (g_strcasecmp (splitstr[1], "ID") == 0)
@@ -3095,11 +3075,12 @@ gdm_handle_user_message (GdmConnection *conn, const gchar *msg, gpointer data)
 			   gdm_connection_printf (conn, "OK false\n");
 			else
 			   gdm_connection_printf (conn, "ERROR 2 Key not valid\n");
+
+			g_strfreev (splitstr);
 		} else {
                		gdm_connection_printf (conn, "ERROR 1 Server not found\n");
 		}
  
-		g_strfreev (splitstr);
 	} else if (strcmp (msg, GDM_SUP_GREETERPIDS) == 0) {
 		GString *msg;
 		GSList *li;
@@ -3129,21 +3110,16 @@ gdm_handle_user_message (GdmConnection *conn, const gchar *msg, gpointer data)
 	} else if (strncmp (msg, GDM_SUP_GET_CONFIG " ",
 		     strlen (GDM_SUP_GET_CONFIG " ")) == 0) {
 		const gchar *parms = &msg[strlen (GDM_SUP_GET_CONFIG " ")];
-		gchar **splitstr   = g_strsplit (parms, " ", 2);
-		gchar *retval      = NULL;
+		gchar **splitstr = g_strsplit (parms, " ", 2);
+		gchar *retval = NULL;
 		static gboolean done_prefetch = FALSE;
 
-		if (splitstr == NULL || splitstr[0] == NULL) {
-               		gdm_connection_printf (conn, "ERROR 50 Unsupported key <null>\n");
-			return;
-		}
-		
 		/*
-		 * It is not meaningful to manage this in a per-display 
-		 * fashion since the prefetch program is only run once the
-		 * for the first display that requests the key.  So process
-		 * this first and return "Unsupported key" for requests
-		 * after the first request.
+		 * If the key is for prefetch do it only once
+		 *
+		 * This key is not managed in per-display fashion, only config 
+		 * values that affect the GUI are.  So okay to process this 
+		 * first.
 		 */
 		if (strcmp (splitstr[0], GDM_KEY_PRE_FETCH_PROGRAM) == 0) {
 			if (done_prefetch) {
@@ -3153,7 +3129,7 @@ gdm_handle_user_message (GdmConnection *conn, const gchar *msg, gpointer data)
 				done_prefetch = TRUE;
 			}
 			return;
-                }
+		}
 
 		if (splitstr[0] != NULL) {
                        /*
@@ -3167,45 +3143,46 @@ gdm_handle_user_message (GdmConnection *conn, const gchar *msg, gpointer data)
    				gdm_connection_printf (conn, "OK %s\n", retval);
    				g_free (retval);
 			} else {
-				/* Check deprecated keys */
-				if (strcmp (splitstr[0],
-				    GDM_KEY_PID_FILE) == 0) {
-					gdm_connection_printf (conn,
-						"OK %s\n", GDM_PID_FILE);
-					return;
-				} else if (gdm_is_valid_key ((gchar *)splitstr[0])) {
+				if (gdm_is_valid_key ((gchar *)splitstr[0]))
 					gdm_connection_printf (conn, "OK \n");
-				} else {
+				else
        		         		gdm_connection_printf (conn,
 						"ERROR 50 Unsupported key <%s>\n",
 						splitstr[0]);
-				}
 			}
 			g_strfreev (splitstr);
 		}
 	} else if (strcmp (msg, GDM_SUP_GET_CONFIG_FILE) == 0) {
+		GString *msg;
+
+		msg = g_string_new ("OK");
+		g_string_append (msg, "\n");
 		gdm_connection_printf (conn, "OK %s\n", config_file);
+		g_string_free (msg, TRUE);
 	} else if (strcmp (msg, GDM_SUP_GET_CUSTOM_CONFIG_FILE) == 0) {
+		GString *msg;
 		gchar *ret;
 
+		msg = g_string_new ("OK");
+		g_string_append (msg, "\n");
 		ret = gdm_get_custom_config_file ();
 		if (ret)
 			gdm_connection_printf (conn, "OK %s\n", ret);
 		else
 			gdm_connection_write (conn,
 					      "ERROR 1 File not found\n");
+		g_string_free (msg, TRUE);
 	} else if (strcmp (msg, GDM_SUP_QUERY_LOGOUT_ACTION) == 0) {
-		GdmLogoutAction logout_action;
-		GdmDisplay *disp;
-		GString *msg;
 		const gchar *sep = " ";
-		gboolean sysmenu;
+		GdmDisplay *disp;
+		GdmLogoutAction logout_action;
+		GString *msg;
+		gboolean sysmenu = gdm_get_value_bool (GDM_KEY_SYSTEM_MENU);
 
 		disp = gdm_connection_get_display (conn);
-		sysmenu = gdm_get_value_bool_per_display (disp->name, GDM_KEY_SYSTEM_MENU);
 
 		/* Only allow locally authenticated connections */
-		if ( ! GDM_CONN_AUTHENTICATED (conn) ||
+		if ( ! GDM_CONN_AUTHENTICATED(conn) ||
 		     disp == NULL) {
 			gdm_info (_("%s request denied: "
 				    "Not authenticated"), "QUERY_LOGOUT_ACTION");
@@ -3250,10 +3227,9 @@ gdm_handle_user_message (GdmConnection *conn, const gchar *msg, gpointer data)
 			&msg[strlen (GDM_SUP_SET_LOGOUT_ACTION " ")];
 		GdmDisplay *disp;
 		gboolean was_ok = FALSE;
-		gboolean sysmenu;
+		gboolean sysmenu = gdm_get_value_bool (GDM_KEY_SYSTEM_MENU);
 
 		disp = gdm_connection_get_display (conn);
-		sysmenu = gdm_get_value_bool_per_display (disp->name, GDM_KEY_SYSTEM_MENU);
 
 		/* Only allow locally authenticated connections */
 		if ( ! GDM_CONN_AUTHENTICATED(conn) ||
@@ -3303,10 +3279,9 @@ gdm_handle_user_message (GdmConnection *conn, const gchar *msg, gpointer data)
 			&msg[strlen (GDM_SUP_SET_SAFE_LOGOUT_ACTION " ")];
 		GdmDisplay *disp;
 		gboolean was_ok = FALSE;
-		gboolean sysmenu;
+		gboolean sysmenu = gdm_get_value_bool (GDM_KEY_SYSTEM_MENU);
 
 		disp = gdm_connection_get_display (conn);
-		sysmenu = gdm_get_value_bool_per_display (disp->name, GDM_KEY_SYSTEM_MENU);
 
 		/* Only allow locally authenticated connections */
 		if ( ! GDM_CONN_AUTHENTICATED(conn) ||
