@@ -18,14 +18,18 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  */
-#include <config.h>
+#include "config.h"
+
 #include <string.h>
 #include <unistd.h>
 #include <stdlib.h>
 #include <locale.h>
-/* we include the include, but don't use it */
-#include <libgnome/libgnome.h>
 
+#ifdef HAVE_CRT_EXTERNS_H
+#include <crt_externs.h>
+#endif
+
+#include "ve-i18n.h"
 #include "ve-misc.h"
 
 char **
@@ -76,7 +80,7 @@ ve_first_word_executable (const char *s, gboolean only_existance)
 	char *bin = ve_first_word (s);
 	if (bin == NULL)
 		return FALSE;
-	if (access (bin, only_existance ? F_OK : X_OK) == 0) {
+	if (g_access (bin, only_existance ? F_OK : X_OK) == 0) {
 		g_free (bin);
 		return TRUE;
 	} else {
@@ -231,7 +235,7 @@ ve_find_file_simple (const char *filename, const GList *directories)
 	if (filename == NULL)
 		return NULL;
 
-	if (access (filename, F_OK) == 0)
+	if (g_access (filename, F_OK) == 0)
 		return g_strdup (filename);
 
 	/* an absolute path is just checked */
@@ -240,7 +244,7 @@ ve_find_file_simple (const char *filename, const GList *directories)
 
 	for (li = directories; li != NULL; li = li->next) {
 		s = g_build_filename (li->data, filename, NULL);
-		if (access (s, F_OK) == 0)
+		if (g_access (s, F_OK) == 0)
 			return s;
 		g_free (s);
 	}
@@ -400,7 +404,12 @@ ve_unsetenv (const char *name)
 #if defined (HAVE_SETENV)
 	unsetenv (name);
 #else
-	extern char **environ;
+
+#ifdef HAVE__NSGETENVIRON
+#define environ (*_NSGetEnviron())
+#else
+        extern char **environ;
+#endif
 	int i, len;
 
 	if (environ == NULL)
@@ -440,7 +449,13 @@ ve_clearenv (void)
 #ifdef HAVE_CLEARENV
 	clearenv ();
 #else
-	extern char **environ;
+
+#ifdef HAVE__NSGETENVIRON
+#define environ (*_NSGetEnviron())
+#else
+        extern char **environ;
+#endif
+
 	if (environ != NULL)
 		environ[0] = NULL;
 #endif
@@ -460,11 +475,13 @@ ve_find_prog_in_path (const char *prog, const char *path)
 		char *full = g_build_filename (vec[i], prog, NULL);
 		/* Do not use X_OK, we may be looking for things
 		   that are not executables */
-		if (access (full, F_OK) == 0) {
+		if (g_access (full, F_OK) == 0) {
+			g_strfreev(vec);
 			return full;
 		}
 		g_free (full);
 	}
+	g_strfreev(vec);
 	return NULL;
 }
 
